#!/bin/sh

QUEUEDIR=/var/spool/mail
LOCKFILE=/tmp/.msmtplock
SPOOL=/var/spool/callweaver/monitor

# write messages to syslog
function log () {
	logger -i -t wms_msmtp $1
}

# is locked return
[ -e "$LOCKFILE" ] && exit 1

[ "$(whoami)" = "root" ] && SUDO="sudo -u wms" || SUDO=""

for com_id in `ls $QUEUEDIR | awk '/^[0-9]$/ {print$0}'`; do
	# change into $QUEUEDIR
	[ -d "$QUEUEDIR/$com_id" ] && cd "$QUEUEDIR/$com_id" || continue;

	# check for empty queuedir
	if [ "`echo *.mail`" = '*.mail' ]; then
		#log "INFO: No mails in $QUEUEDIR/$com_id" #FIXME
		#exit 0
		continue
	fi

	# lock the $QUEUEDIR
	touch "$LOCKFILE" || exit 1

	# process all mails
	for MAILFILE in *.mail; do
		log "INFO: Sending $MAILFILE..."
		MSMTPFILE="`echo $MAILFILE | sed -e 's/\.mail$/\.msmtp/'`"
		if [ ! -f "$MSMTPFILE" ]; then
			log "INFO: No corresponding file $MSMTPFILE found. Removing $MAILFILE"
			rm $MAILFILE
			continue
		fi
		to=`cat "$MSMTPFILE"`
		$SUDO msmtp --syslog --file=/etc/companies.d/$com_id/msmtprc $to < $MAILFILE 1>/dev/null 2>&1
		ret=$?
		if [ $ret -eq 0 ]; then
			rm "$MAILFILE" "$MSMTPFILE"
			log "INFO: $MAILFILE sent successfully"
		elif [ $ret -eq 68 ]; then
			log "INFO: Host name unknown. $MAILFILE not sent. Try later"
		elif [ $ret -eq 75 ]; then
			log "INFO: Temp failure; user is invited to retry. $MAILFILE not sent"
		elif [ $ret -ne 0 ]; then
			log "ERROR: File $MAILFILE is wrong! Server retur error: $ret. $MAILFILE not send. Removing it..."
			rm "$MAILFILE" "$MSMTPFILE"
		fi
	done
	
	# find old files and remove them
#	find /var/spool/callweaver/monitor -type f -name \*.wav -mmin +31 -exec rm {} \;
	find /tmp -type f -name \*.wav -mmin +20 -exec rm {} \;

	# remove the lock
	rm -f "$LOCKFILE"
done
exit 0
